summaryrefslogtreecommitdiffstats
path: root/kdeui/klistbox.h
diff options
context:
space:
mode:
Diffstat (limited to 'kdeui/klistbox.h')
-rw-r--r--kdeui/klistbox.h44
1 files changed, 22 insertions, 22 deletions
diff --git a/kdeui/klistbox.h b/kdeui/klistbox.h
index ec1afc29f..b19819c79 100644
--- a/kdeui/klistbox.h
+++ b/kdeui/klistbox.h
@@ -18,31 +18,31 @@
#ifndef KLISTBOX_H
#define KLISTBOX_H
-#include <qlistbox.h>
+#include <tqlistbox.h>
#include <kdelibs_export.h>
/**
* @short A variant of QListBox that honors KDE's system-wide settings.
*
* Extends the functionality of QListBox to honor the system
* wide settings for Single Click/Double Click mode, Auto Selection and
* Change Cursor over Link.
*
* There is a new signal executed(). It gets connected to either
* QListBox::clicked() or QListBox::doubleClicked()
* depending on the KDE wide Single Click/Double Click settings. It is
* strongly recommended that you use this signal instead of the above
* mentioned. This way you don't need to care about the current
* settings. If you want to get informed when the user selects
* something connect to the QListBox::selectionChanged() signal.
**/
class KDEUI_EXPORT KListBox : public QListBox
{
Q_OBJECT
public:
- KListBox( QWidget *parent = 0, const char *name = 0, WFlags f = 0 );
+ KListBox( TQWidget *parent = 0, const char *name = 0, WFlags f = 0 );
signals:
@@ -53,10 +53,10 @@ signals:
* setting the user clicked or double clicked on that item.
* @param item is the pointer to the executed listbox item.
*
* Note that you may not delete any QListBoxItem objects in slots
* connected to this signal.
*/
- void executed( QListBoxItem *item );
+ void executed( TQListBoxItem *item );
/**
* Emitted whenever the user executes an listbox item.
@@ -66,10 +66,10 @@ signals:
* @param item is the pointer to the executed listbox item.
* @param pos is the position where the user has clicked
*
* Note that you may not delete any QListBoxItem objects in slots
* connected to this signal.
*/
- void executed( QListBoxItem *item, const QPoint &pos );
+ void executed( TQListBoxItem *item, const TQPoint &pos );
/**
* This signal gets emitted whenever the user double clicks into the
@@ -78,17 +78,17 @@ signals:
* @param item The pointer to the clicked listbox item.
* @param pos The position where the user has clicked.
*
* Note that you may not delete any QListBoxItem objects in slots
* connected to this signal.
*
* This signal is more or less here for the sake of completeness.
* You should normally not need to use this. In most cases it's better
* to use executed() instead.
*/
- void doubleClicked( QListBoxItem *item, const QPoint &pos );
+ void doubleClicked( TQListBoxItem *item, const TQPoint &pos );
protected slots:
- void slotOnItem( QListBoxItem *item );
+ void slotOnItem( TQListBoxItem *item );
void slotOnViewport();
void slotSettingsChanged(int);
@@ -99,24 +99,24 @@ protected slots:
void slotAutoSelect();
protected:
- void emitExecute( QListBoxItem *item, const QPoint &pos );
+ void emitExecute( TQListBoxItem *item, const TQPoint &pos );
- virtual void keyPressEvent(QKeyEvent *e);
- virtual void focusOutEvent( QFocusEvent *fe );
- virtual void leaveEvent( QEvent *e );
- virtual void contentsMousePressEvent( QMouseEvent *e );
- virtual void contentsMouseDoubleClickEvent ( QMouseEvent *e );
+ virtual void keyPressEvent(TQKeyEvent *e);
+ virtual void focusOutEvent( TQFocusEvent *fe );
+ virtual void leaveEvent( TQEvent *e );
+ virtual void contentsMousePressEvent( TQMouseEvent *e );
+ virtual void contentsMouseDoubleClickEvent ( TQMouseEvent *e );
bool m_bUseSingle;
bool m_bChangeCursorOverItem;
- QListBoxItem* m_pCurrentItem;
+ TQListBoxItem* m_pCurrentItem;
- QTimer* m_pAutoSelect;
+ TQTimer* m_pAutoSelect;
int m_autoSelectDelay;
private slots:
- void slotMouseButtonClicked( int btn, QListBoxItem *item, const QPoint &pos );
+ void slotMouseButtonClicked( int btn, TQListBoxItem *item, const TQPoint &pos );
protected:
virtual void virtual_hook( int id, void* data );
@@ -18,31 +18,31 @@
#include <kdelibs_export.h>
/**
- * @short A variant of QListBox that honors KDE's system-wide settings.
+ * @short A variant of TQListBox that honors KDE's system-wide settings.
*
@@ -18,31 +18,31 @@
*
- * Extends the functionality of QListBox to honor the system
+ * Extends the functionality of TQListBox to honor the system
* wide settings for Single Click/Double Click mode, Auto Selection and
* Change Cursor over Link.
@@ -18,31 +18,31 @@
*
* There is a new signal executed(). It gets connected to either
- * QListBox::clicked() or QListBox::doubleClicked()
+ * TQListBox::clicked() or TQListBox::doubleClicked()
* depending on the KDE wide Single Click/Double Click settings. It is
* strongly recommended that you use this signal instead of the above
@@ -18,31 +18,31 @@
* mentioned. This way you don't need to care about the current
* settings. If you want to get informed when the user selects
- * something connect to the QListBox::selectionChanged() signal.
+ * something connect to the TQListBox::selectionChanged() signal.
**/
class KDEUI_EXPORT KListBox : public QListBox
@@ -53,10 +53,10 @@ signals:
* @param item is the pointer to the executed listbox item.
*
- * Note that you may not delete any QListBoxItem objects in slots
+ * Note that you may not delete any TQListBoxItem objects in slots
* connected to this signal.
*/
@@ -66,10 +66,10 @@ signals:
* @param pos is the position where the user has clicked
*
- * Note that you may not delete any QListBoxItem objects in slots
+ * Note that you may not delete any TQListBoxItem objects in slots
* connected to this signal.
*/
@@ -78,17 +78,17 @@ signals:
* @param pos The position where the user has clicked.
*
- * Note that you may not delete any QListBoxItem objects in slots
+ * Note that you may not delete any TQListBoxItem objects in slots
* connected to this signal.
*